@@ -1,5 +1,5 @@
 package Pod::Elemental::Element::Pod5::Region;
-our $VERSION = '0.092941';
+our $VERSION = '0.092970';
 
 
 # ABSTRACT: a region of Pod (this role likely to be removed)
@@ -71,7 +71,7 @@ sub __as_pod_string_begin {
 
   $string .= $self->children->map(sub { $_->as_pod_string })->join(q{});
 
-  $string .= "\n"
+  $string .= "\n\n"
     if  $self->children->length
     and $self->children->[-1]->isa( 'Pod::Elemental::Element::Pod5::Data');
     # Pod5::$self->is_pod; # XXX: HACK!! -- rjbs, 2009-10-21
@@ -123,7 +123,7 @@ Pod::Elemental::Element::Pod5::Region - a region of Pod (this role likely to be
 
 =head1 VERSION
 
-version 0.092941
+version 0.092970
 
 =head1 WARNING
 
