@@ -1,5 +1,5 @@
 package Pod::Elemental::Transformer::Pod5;
-our $VERSION = '0.092941';
+our $VERSION = '0.092970';
 
 
 use Moose;
@@ -192,11 +192,7 @@ sub _collect_runs {
 
     my @to_collect = ($start);
     NEXT: for my $next ($start+1 .. $#$paras) {
-      if (
-        $paras->[ $next ]->isa($class)
-        or
-        s_blank($paras->[ $next ])
-      ) {
+      if ($paras->[ $next ]->isa($class) or s_blank($paras->[ $next ])) {
         push @to_collect, $next;
         next NEXT;
       }
@@ -210,8 +206,8 @@ sub _collect_runs {
 
     my $new_content = $paras
                     ->slice(\@to_collect)
-                    ->map(sub { $_->content })
-                    ->join(q{});
+                    ->map(sub { $_ = $_->content; chomp; $_ })
+                    ->join(qq{\n});
 
     splice @$paras, $start, scalar(@to_collect), $class->new({
       content => $new_content,
@@ -251,7 +247,7 @@ Pod::Elemental::Transformer::Pod5 - the default, minimal semantics of Perl5's po
 
 =head1 VERSION
 
-version 0.092941
+version 0.092970
 
 =head1 SYNOPSIS
 
